Merge branch 'master' of github.com:open-cloud/xos
diff --git a/planetstack/core/context_processors.py b/planetstack/core/context_processors.py
index 9cfcaa6..5933352 100644
--- a/planetstack/core/context_processors.py
+++ b/planetstack/core/context_processors.py
@@ -2,7 +2,7 @@
 from core.models import Site
 
 
-def planetstack(request):
+def xos(request):
     allSites = []
     for site in Site.objects.all():
         allowNewUsers = True    # replace with logic for blessing sites for registration, if necessary
diff --git a/planetstack/xos/settings.py b/planetstack/xos/settings.py
index 63696c8..f1f4885 100644
--- a/planetstack/xos/settings.py
+++ b/planetstack/xos/settings.py
@@ -1,7 +1,7 @@
 from django.conf.global_settings import TEMPLATE_CONTEXT_PROCESSORS as TCP
 from django import VERSION as DJANGO_VERSION
 
 # Django settings for planetstack project.
 from config import Config
 config = Config()
 
@@ -162,7 +162,7 @@
 # Added for django-suit form 
 TEMPLATE_CONTEXT_PROCESSORS = TCP + (
     'django.core.context_processors.request',
-    'core.context_processors.planetstack',
+    'core.context_processors.xos',
 )
 
 # Django Suit configuration example
@@ -193,7 +193,6 @@
          'core.deploymentrole',
          'core.siterole',
          'core.slicerole',
-         'core.planetstackrole',
          'core.networktemplate',
          'core.networkparametertype',
          'core.router',
@@ -1,7 +1,7 @@
 from django import VERSION as DJANGO_VERSION
 
-# Django settings for planetstack project.
+# Django settings for XOS.
 from config import Config
 config = Config()